AgentNameAndVersionSet

Struct AgentNameAndVersionSet 

pub struct AgentNameAndVersionSet(/* private fields */);
Encapsulates choices of Agent and Version of that agent

Implementations

Source

impl AgentNameAndVersionSet

pub fn support_for_a_feature<'a, F: FnMut(&Agent<'_>, &Version, &Support<'_>)>( &self, can_i_use: &'a CanIUse, feature_name: &'a FeatureName, support_user: F, )

Find support for implementations of a feature; useful for downstream applications, eg to find prefixes to autoprefix CSS with

pub fn feature<'a, F: FnMut(&Agent<'_>, &Version, Option<Option<Support<'_>>>)>( &self, can_i_use: &'a CanIUse, feature_name: &'a FeatureName, feature_implementation_user: F, )

Find out about a feature

pub fn new(values: HashSet<(AgentName, Version)>) -> Self

Constructor to use if one of the methods below isn’t suitable

pub fn a_sensible_set_of_choices_for_an_international_website_in_multiple_languages( can_i_use: &CanIUse, maximum_release_age_from_can_i_use_database_last_updated: Duration, minimum_usage_threshold: UsagePercentage, regional_usages: &[&RegionalUsage], ) -> Self

A sensible set of choices for an international website in multiple languages

pub fn sensible_choices( can_i_use: &CanIUse, maximum_release_age_from_can_i_use_database_last_updated: Duration, minimum_usage_threshold: UsagePercentage, regional_usages: &[&RegionalUsage], obsolete_browsers_still_in_use: Self, browsers_which_underwent_a_major_change_of_rendering_engine: Self, automatically_updated_browsers: HashSet<AgentName>, long_term_releases_of_automatically_updated_browsers: HashSet<AgentName>, regionally_significant_occasionally_automatically_updated_browsers: HashSet<AgentName>, ) -> Self

A sensible set of rules that makes sure:-

  • obsolete but still-used browsers are included
  • browsers with a major change of rendering engine but still-used are included
  • automatically updated or long-term supported browsers are included
  • regionally significant and not necessarily frequently updated browsers are included
pub fn add_just_these_versions_by_usage_percentage( &mut self, obsolete_or_changed_rendering_engine: &Self, regional_usage: &RegionalUsage, minimum_usage_threshold: UsagePercentage, )

Adds browser-version combination if it exceeds minimum usage threshold for region

pub fn add_any_current_or_older_version_by_usage_percentage( &mut self, agent_names: &HashSet<AgentName>, regional_usage: &RegionalUsage, minimum_usage_threshold: UsagePercentage, can_i_use: &CanIUse, )

Adds browser-version combination for any current or older version if it exceeds or equals minimum usage threshold for region

pub fn add_any_current_or_older_version_by_age( &mut self, agent_names: &HashSet<AgentName>, oldest_release_date: DateTime<Utc>, can_i_use: &CanIUse, )

Adds browser-version combination if it exceeds or equals oldest release date

pub fn obsolete_browsers_still_in_use() -> Self

Obsolete browsers still in use. We need to support the last version of these until its percentage usage falls below X%. The percentage usage (X%) should be for a sub-set of the world (ie target audience continents or countries). Returns a list of (Agent, Last-Known-Version) pairs.

pub fn browsers_which_underwent_a_major_change_of_rendering_engine() -> Self

Browsers which underwent a major change of rendering engine. We need to support the last version of these until its percentage usage falls below X%. The percentage usage (X%) should be for a sub-set of the world (ie target audience continents or countries). Returns a list of (Agent, Last-Known-Version-before-change-of-rendering-engine) pairs.

pub fn automatically_updated_browsers() -> HashSet<AgentName>

Browsers which are regularly updated, automatically and so which do not ‘hang around’. These browsers have short-lived, sub-yearly versions They are probably best discovered by matching for all released versions after a specific release date (eg 2 years ago) Using a percentage isn’t wise as usage of each version will change rapidly (from near zero to a few percentage points, then to near zero again), and certainly likely to change more rapidly than static website rebuilds.

pub fn long_term_releases_of_automatically_updated_browsers() -> HashSet<AgentName>

Long-Term Releases of Automatically Updated Browsers. These browsers have occasional long-term releases which are intended to be supported for a year or more. Usage percentages for these may be very low globally, and they may be 9 or more release versions ‘out-of-date’, but they represent an important audience. In practice the length of time each long term release is supported for changes with each release, even though vendors have ‘long term release policies’. This is because policies change in the long interval between long-term releases. These browsers are problematic to identify as the caniuse.com database omits them. Some long-term release versions differ slightly in supported features, particularly those of a more experimental nature, to their related short-term release cousins (even though they may share the same major version number). For Firefox, ESR releases are supposedly for one year (actually, 54 weeks, ‘9-cycles’, with a 12-week (‘2-cycle’) overlap between releases (a cycle is a Firefox release cycle, typically 6 weeks), but, as always for these sorts of releases, the policy has changed several times.

pub fn regionally_significant_occasionally_automatically_updated_browsers() -> HashSet<AgentName>

Regionally significant, occasionally automatically updated browsers. Support of these browsers is particularly important for the Indian and Asian markets. Many cheaper smart phones come with them (I’ve used them, too). Vendors frequently don’t upgrade old firmware installed versions and some older versions may persist and have higher usage for some time than newer ones. All of them currently are just more dated versions of the Webkit rendering engine than Chrome. These browsers are probably best supported with a ‘above X% rule’, where X is for any version.

Methods from Deref<Target = HashSet<(AgentName, Version)>>

1.0.0 · Source

pub fn capacity(&self) -> usize

Returns the number of elements the set can hold without reallocating.

Examples
use std::collections::HashSet;
let set: HashSet<i32> = HashSet::with_capacity(100);
assert!(set.capacity() >= 100);
1.0.0 · Source

pub fn iter(&self) -> Iter<'_, T>

An iterator visiting all elements in arbitrary order. The iterator element type is &'a T.

Examples
use std::collections::HashSet;
let mut set = HashSet::new();
set.insert("a");
set.insert("b");

// Will print in an arbitrary order.
for x in set.iter() {
    println!("{x}");
}
Performance

In the current implementation, iterating over set takes O(capacity) time instead of O(len) because it internally visits empty buckets too.

1.0.0 · Source

pub fn len(&self) -> usize

Returns the number of elements in the set.

Examples
use std::collections::HashSet;

let mut v = HashSet::new();
assert_eq!(v.len(), 0);
v.insert(1);
assert_eq!(v.len(), 1);
1.0.0 · Source

pub fn is_empty(&self) -> bool

Returns true if the set contains no elements.

Examples
use std::collections::HashSet;

let mut v = HashSet::new();
assert!(v.is_empty());
v.insert(1);
assert!(!v.is_empty());
1.9.0 · Source

pub fn hasher(&self) -> &S

Returns a reference to the set’s BuildHasher.

Examples
use std::collections::HashSet;
use std::hash::RandomState;

let hasher = RandomState::new();
let set: HashSet<i32> = HashSet::with_hasher(hasher);
let hasher: &RandomState = set.hasher();
1.0.0 · Source

pub fn difference<'a>( &'a self, other: &'a HashSet<T, S>, ) -> Difference<'a, T, S>

Visits the values representing the difference, i.e., the values that are in self but not in other.

Examples
use std::collections::HashSet;
let a = HashSet::from([1, 2, 3]);
let b = HashSet::from([4, 2, 3, 4]);

// Can be seen as `a - b`.
for x in a.difference(&b) {
    println!("{x}"); // Print 1
}

let diff: HashSet<_> = a.difference(&b).collect();
assert_eq!(diff, [1].iter().collect());

// Note that difference is not symmetric,
// and `b - a` means something else:
let diff: HashSet<_> = b.difference(&a).collect();
assert_eq!(diff, [4].iter().collect());
1.0.0 · Source

pub fn symmetric_difference<'a>( &'a self, other: &'a HashSet<T, S>, ) -> SymmetricDifference<'a, T, S>

Visits the values representing the symmetric difference, i.e., the values that are in self or in other but not in both.

Examples
use std::collections::HashSet;
let a = HashSet::from([1, 2, 3]);
let b = HashSet::from([4, 2, 3, 4]);

// Print 1, 4 in arbitrary order.
for x in a.symmetric_difference(&b) {
    println!("{x}");
}

let diff1: HashSet<_> = a.symmetric_difference(&b).collect();
let diff2: HashSet<_> = b.symmetric_difference(&a).collect();

assert_eq!(diff1, diff2);
assert_eq!(diff1, [1, 4].iter().collect());
1.0.0 · Source

pub fn intersection<'a>( &'a self, other: &'a HashSet<T, S>, ) -> Intersection<'a, T, S>

Visits the values representing the intersection, i.e., the values that are both in self and other.

When an equal element is present in self and other then the resulting Intersection may yield references to one or the other. This can be relevant if T contains fields which are not compared by its Eq implementation, and may hold different value between the two equal copies of T in the two sets.

Examples
use std::collections::HashSet;
let a = HashSet::from([1, 2, 3]);
let b = HashSet::from([4, 2, 3, 4]);

// Print 2, 3 in arbitrary order.
for x in a.intersection(&b) {
    println!("{x}");
}

let intersection: HashSet<_> = a.intersection(&b).collect();
assert_eq!(intersection, [2, 3].iter().collect());
1.0.0 · Source

pub fn union<'a>(&'a self, other: &'a HashSet<T, S>) -> Union<'a, T, S>

Visits the values representing the union, i.e., all the values in self or other, without duplicates.

Examples
use std::collections::HashSet;
let a = HashSet::from([1, 2, 3]);
let b = HashSet::from([4, 2, 3, 4]);

// Print 1, 2, 3, 4 in arbitrary order.
for x in a.union(&b) {
    println!("{x}");
}

let union: HashSet<_> = a.union(&b).collect();
assert_eq!(union, [1, 2, 3, 4].iter().collect());
1.0.0 · Source

pub fn contains<Q>(&self, value: &Q) -> bool
where T: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns true if the set contains a value.

The value may be any borrowed form of the set’s value type, but Hash and Eq on the borrowed form must match those for the value type.

Examples
use std::collections::HashSet;

let set = HashSet::from([1, 2, 3]);
assert_eq!(set.contains(&1), true);
assert_eq!(set.contains(&4), false);
1.9.0 · Source

pub fn get<Q>(&self, value: &Q) -> Option<&T>
where T: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns a reference to the value in the set, if any, that is equal to the given value.

The value may be any borrowed form of the set’s value type, but Hash and Eq on the borrowed form must match those for the value type.

Examples
use std::collections::HashSet;

let set = HashSet::from([1, 2, 3]);
assert_eq!(set.get(&2), Some(&2));
assert_eq!(set.get(&4), None);
1.0.0 · Source

pub fn is_disjoint(&self, other: &HashSet<T, S>) -> bool

Returns true if self has no elements in common with other. This is equivalent to checking for an empty intersection.

Examples
use std::collections::HashSet;

let a = HashSet::from([1, 2, 3]);
let mut b = HashSet::new();

assert_eq!(a.is_disjoint(&b), true);
b.insert(4);
assert_eq!(a.is_disjoint(&b), true);
b.insert(1);
assert_eq!(a.is_disjoint(&b), false);
1.0.0 · Source

pub fn is_subset(&self, other: &HashSet<T, S>) -> bool

Returns true if the set is a subset of another, i.e., other contains at least all the values in self.

Examples
use std::collections::HashSet;

let sup = HashSet::from([1, 2, 3]);
let mut set = HashSet::new();

assert_eq!(set.is_subset(&sup), true);
set.insert(2);
assert_eq!(set.is_subset(&sup), true);
set.insert(4);
assert_eq!(set.is_subset(&sup), false);
1.0.0 · Source

pub fn is_superset(&self, other: &HashSet<T, S>) -> bool

Returns true if the set is a superset of another, i.e., self contains at least all the values in other.

Examples
use std::collections::HashSet;

let sub = HashSet::from([1, 2]);
let mut set = HashSet::new();

assert_eq!(set.is_superset(&sub), false);

set.insert(0);
set.insert(1);
assert_eq!(set.is_superset(&sub), false);

set.insert(2);
assert_eq!(set.is_superset(&sub), true);