VersionDetail

Struct VersionDetail 

pub struct VersionDetail { /* private fields */ }
Details about a particular version, of which only the release_date is particularly useful. The era is a relative value which can change with releases of the caniuse.com database, and the global_usage can differ to that available in RegionalUsage::WorldWide.

Implementations

Source

impl VersionDetail

pub fn global_usage(&self) -> UsagePercentage

A global usage of this version; one of three measurements included in the caniuse.com database. It is recommended to use that in the RegionalUsage::WorldWide database instead as RegionalUsage data has greater consistency.

pub fn release_date(&self) -> Option<DateTime<Utc>>

A timestamp of when this particular version was released. It is likely that the hours, minutes and seconds represent false precision. If the release_date is None, then ordinarily this version has not yet been released and self.era() should be greater than zero (0).

pub fn era(&self) -> i64

Eras are the caniuse.com database’s attempt to align different browsers by version. Negative values are for not current versions. Zero is for the current version. The era is a relative value which which can change with releases of the caniuse.com database.

pub fn prefix_override(&self) -> Option<&Prefix>

Override of prefix; only specified for Opera